FancyDioInspectorConsoleOptions class

Constructors

FancyDioInspectorConsoleOptions({bool verbose = false, bool colorize = true, String requestName = FancyStrings.requestUpperCased, String responseName = FancyStrings.responseUpperCased, String errorName = FancyStrings.errorUpperCased, FancyConsoleTextColors requestColor = FancyConsoleTextColors.yellow, FancyConsoleTextColors responseColor = FancyConsoleTextColors.green, FancyConsoleTextColors errorColor = FancyConsoleTextColors.red})
const

Properties

colorize bool
It controls whether to colorize the console or not if verbose is true. If verbose is false, this option is ignored.
final
errorColor FancyConsoleTextColors
It is the color of the error displayed in the console. colorize must be true. If colorize is false, this option is ignored.
final
errorName String
It is the name of the error displayed in the console.
final
hashCode int
The hash code for this object.
no setterinherited
requestColor FancyConsoleTextColors
It is the color of the request displayed in the console. colorize must be true. If colorize is false, this option is ignored.
final
requestName String
It is the name of the request displayed in the console.
final
responseColor FancyConsoleTextColors
It is the color of the response displayed in the console. colorize must be true. If colorize is false, this option is ignored.
final
responseName String
It is the name of the response displayed in the console.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
It controls whether to log to the console or not.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited