FancyDioInspectorTileOptions class

It is used to configure the FancyDioInspectorView widget.

Constructors

FancyDioInspectorTileOptions({bool showButtons = true, bool showSearch = true, int? maxCharacters, int? maxLines})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxCharacters int?
It controls the maximum number of characters to be shown in the tile. If the length of the string is greater than the maxCharacters, then the string will be truncated and ... will be appended at the end.
final
maxLines int?
It controls the maximum number of lines to be shown in the tile. If the number of lines of the string is greater than the maxLines, then the string will be truncated and ... will be appended at the end.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showButtons bool
It controls whether to show copy buttons or not.
final
showSearch bool
It controls whether to show the search field to filter elements or not.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited