HttpScopeView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- HttpScopeView
Constructors
-
HttpScopeView({Key? key, Widget? leading, List<
Widget> ? actions, HttpScopeViewConfig viewConfig = const HttpScopeViewConfig()}) -
const
Properties
-
actions
→ List<
Widget> ? -
actions are used to place widgets after the title.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leading → Widget?
-
The options for the dio tiles.
If this is
null, the default options will be used. The options for the UI localization. If any of the value isnull, the default value will be used. leading is used to place a widget before the title.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewConfig → HttpScopeViewConfig
-
The theme data for the view. If this is
null,FancyThemeDatawill be used.final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited