leading property
The options for the dio tiles.
If this is null, the default options will be used.
The options for the UI localization.
If any of the value is null, the default value will be used.
leading is used to place a widget before the title.
Implementation
// final FancyDioInspectorTileOptions tileOptions;
/// The options for the UI localization.
/// If any of the value is `null`, the default value will be used.
// final FancyDioInspectorL10nOptions l10nOptions;
/// [leading] is used to place a widget before the title.
final Widget? leading;