HttpScopeViewConfig class

Constructors

HttpScopeViewConfig({bool recordFilter(HttpRecord record)?, String? manualUrl, void onOpenManual(String manualUrl)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
manualUrl String?
The URL to open when the user taps the help button in HttpScopeView. If null, a sensible default pointing to the repository manual will be used.
final
onOpenManual → void Function(String manualUrl)?
Optional manual opener. If provided, it will be used to open manualUrl (or the default manual URL). This allows apps to integrate their own launching logic without adding extra dependencies in this package.
final
recordFilter bool Function(HttpRecord record)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited