manualUrl property

String? manualUrl
final

The URL to open when the user taps the help button in HttpScopeView. If null, a sensible default pointing to the repository manual will be used.

Implementation

final String? manualUrl;