onOpenManual property
Optional manual opener. If provided, it will be used to open manualUrl (or the default manual URL). This allows apps to integrate their own launching logic without adding extra dependencies in this package.
Implementation
final void Function(String manualUrl)? onOpenManual;