HttpInspectorOptions class

This is used to configure the HttpInspector package.

Constructors

HttpInspectorOptions({bool logRequests = true, bool logResponses = true, bool logErrors = true, int maxLogs = 50, HttpInspectorConsoleOptions consoleOptions = const HttpInspectorConsoleOptions()})
const

Properties

consoleOptions HttpInspectorConsoleOptions
It controls the console logging options.
final
hashCode int
The hash code for this object.
no setterinherited
logErrors bool
It controls whether to log errors or not.
final
logRequests bool
It controls whether to log requests or not.
final
logResponses bool
It controls whether to log responses or not.
final
maxLogs int
It controls the maximum number of logs to be stored.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited