FancyDioInterceptor class
Constructors
- FancyDioInterceptor({FancyDioInspectorOptions options = const FancyDioInspectorOptions(), OnRequestCreated? onRequestCreated, OnResponseCreated? onResponseCreated, OnErrorCreated? onErrorCreated})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → FancyDioLogger
-
no setter
- onErrorCreated → OnErrorCreated?
-
final
- onRequestCreated → OnRequestCreated?
-
final
- onResponseCreated → OnResponseCreated?
-
final
- options → FancyDioInspectorOptions
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException err, ErrorInterceptorHandler handler) → void - Called when an exception was occurred during the request.
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → void - Called when the request is about to be sent.
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void - Called when the response is about to be resolved.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited