manualUrl property
The URL to open when the user taps the help button in HttpScopeView. If null, a sensible default pointing to the repository manual will be used.
Implementation
final String? manualUrl;
The URL to open when the user taps the help button in HttpScopeView. If null, a sensible default pointing to the repository manual will be used.
final String? manualUrl;